const utils = require('../utils/utils.js')
module.exports = {
  name: 'use',
  alias: ['u'],
  run: async toolbox => {
    const {
      parameters,
      template: { mobile },
      print: { info, success, error, spin, table },
      filesystem: fs,
      system: { exec },
      patching
    } = toolbox

    if (parameters.first === 'help') {
      return showHelpMessage(info, table)
    }
    let CLIENT = parameters.first
    let VERSION = parameters.options.version
    const timestamp = Date.now() / 1000 / 60

    let clients = await fs.listAsync('templates')

    if (!clients) {
      return error(
        '\n Current working directory is not a Ontrac-based project. \n'
      )
    }
    clients = clients.filter(item => item != '.DS_Store')
    if (!CLIENT) {
      CLIENT = await utils.ask('Select', 'Select an enviroment', clients)
    }
    if (!VERSION) VERSION = await utils.ask('Input', 'Version number')
    if (!VERSION) VERSION = '0.0.0'
    await updateFiles(VERSION, CLIENT, timestamp, fs)
    info('')
    table(
      [
        ['Project', 'Version'],
        [CLIENT.toUpperCase(), VERSION]
      ],
      {
        format: 'lean'
      }
    )
    info('')
  }
}

let updateFiles = async (VERSION, CLIENT, timestamp, fs) => {
  await utils.updateVersion(VERSION, timestamp, fs)
  await utils.updateConfigXml(CLIENT, fs)
  await utils.updatePackageJson(CLIENT, fs)
  await utils.updateIndexHtml(CLIENT, fs)
  await utils.deleteAndCopyFiles(CLIENT, fs)
}

let showHelpMessage = (info, table) => {
  info('')
  info('HOW TO USE: \n ontrac use CLIENT --version=0.0.0 \n')
  table(
    [
      ['Command', 'Description'],
      ['--version', '0.0.0']
    ],
    {
      format: 'lean'
    }
  )
  info('')
}
